@@ -40,7 +40,7 @@ struct dp_handle {
 
 /* functions to set up a handle (which is basically just a pcap handle) */
 
-struct dp_handle * dp_open_live(char * device, int snaplen, int promisc, int to_ms, char * ebuf);
+struct dp_handle * dp_open_live(const char * device, int snaplen, int promisc, int to_ms, const char * ebuf);
 struct dp_handle * dp_open_offline(char * fname, char * ebuf);
 
 /* functions to add callbacks */
