@@ -17,7 +17,7 @@ enum direction {
 
 /* To initialise this module, call getLocal with the currently
  * monitored device (e.g. "eth0:1") */
-void getLocal (const char *device);
+void getLocal (const char *device, bool tracemode);
 
 class Packet
 {
